---
title: 위드소프트/플렉스지 가입신청 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 호스팅 제휴
seo:
  title: 위드소프트/플렉스지 가입신청 방법
  description: >-
    위드소프트 "플렉스지"의 토스페이먼츠 PG 가입신청 안내입니다. '결제방식'별로 토스페이먼츠 홈페이지를 통해 추가 신청 절차가
    필요합니다.
  keywords:
    - 토스페이먼츠
tags:
  - 토스페이먼츠
  - 호스팅 제휴
  - 위드소프트
  - 플렉스지
pgCompanies:
  - 토스페이먼츠
searchTags:
  - 플렉스지
  - 위드소프트
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="위드소프트 &quot;플렉스지&quot; 토스페이먼츠 PG 가입신청 방법을 알려드립니다." title="" />

**위드소프트 [플렉스지 홈페이지 보러 가기 ↗ ](https://flexgate.co.kr/)**

#### **토스페이먼츠 가입 신청**

1. [토스페이먼츠 홈페이지↗](https://app.tosspayments.com) 접속 > 회원 가입 > 로그인 > "결제 서비스 신청하기" 선택
2. 사업자등록번호 입력
3. 호스팅사에서 제공하는 쇼핑몰 구축 서비스를 이용 중이신가요? > “네” 선택
4. 이용중인 호스팅사를 선택하세요 > "그 외" 선택 후 검색란에 **"위드소프트"** 입력 후 \[검색] 클릭
5. 결제방식별 구분

- 일반 결제 : "포트원\_위드소프트" 선택 해 주세요. → 부가 결제수단 '휴대폰결제' 선택
- 수기 결제 : "포트원\_위드소프트\_빌링 선택 해 주세요.
- 간편 결제 : "포트원\_위드소프트\_간편결제" 선택 해 주세요. → 부가 결제수단 '카카오페이','네이버페이' 선택

6\. 결제수단/수수료 체크 후 동의

7\. 홈페이지 정보(사이트 URL) 입력

8\. 대표자/담당자/위임서류 등 토스페이먼츠에서 요구하는 가입신청 접수 정보 등록

9\. 가입 신청 완료

<Callout content="토스페이먼츠 홈페이지를 통해 '결제방식'별로 추가 신청 절차가 필요합니다.
- 자주 찾는 메뉴 > 결제 서비스 신청하기 > [내 상점에 결제 서비스 추가] 선택 후 2번~8번 절차를 반복 진행 해 주시기 바랍니다.

신청 후 약 3일 이내 (영업일기준) 토스페이먼츠 계약담당자가 배정되어 직접 계약절차 및 계약서류와 관련하여 연락을 드리며, 가입신청 ~ 계약/심사완료까지는 약 3주 이상 소요 될 수 있습니다.

토스페이먼츠 홈페이지 내 가입신청서 작성방법 및 계약 서류 등 관련 문의 사항은 토스페이먼츠 고객센터로 문의주시기 바랍니다.
(토스페이먼츠 고객센터 : 1544-7772 > 신규계약 3번)
" title="참고 사항" icon="💡" />

### **토스페이먼츠\_신모듈\_API  설정하기**

- [토스페이먼츠 개발자센터 ](https://developers.tosspayments.com/) 로그인 >
- 개발정보 > 테스트/라이브 각각 설정 > API 버전 “2022-07-27” 설정

### **토스페이먼츠\_상점 연동 정보 조회/전달**

- [토스페이먼츠 개발자센터 ](https://developers.tosspayments.com/) 로그인 >
- \[테스트 모드] 내 개발정보 - '테스트' 클릭 또는 \[실운영 모드] 내 개발정보 - '라이브' 클릭
- 상점아이디(MID)와 API키(클라이언트키&시크릿키) 를 "플렉스지"로 전달 해 주세요.

※ 토스페이먼츠 상점ID(MID)는 일반/정기/간편 결제방식별로 발급되므로,"**상점**" 드롭다운(화살표 클릭) 에서 선택하셔서 조회 해 주세요.

